## **Agente para criação de Documentos tecnicos** 
- **06/01/2024**  
  - Conceito: Agente para criação de Documentos tecnicos com descriçoes tecnicas de funcoes e seus objetivos o objetivo do agente é criar uma base de conhecimento sobre o software para que outro agente da equipe de suporte possa saber como responder perguntas profundas e razas sobre o software
  - Anotacoes: com esse agente teremos controle total sobre tudo que compoe o software isso é de fato bem interressante visto que desenvolver um documento tecnico enquanto ou depois do desenvolvimento é muitas vezes completamente inviavel

